# -*- coding: utf8 -*-

from .smb_lib import addGrapheInfluence, addCTL , runSMBionet, resultSMBionet, SmbionetException


__all__ = ['addGrapheInfluence', 'addCTL', 'runSMBionet','resultSMBionet', 'SmbionetException']


# -*- coding: utf8 -*-

from setuptools import setup, find_packages

setup(name="smb-lib",
    version='0.0.6',
    author = "Mohamed Chennouf",
    author_email = "mohamed.chennouf@etu.unice.fr",
    url = "https://github.com/clement-alexandre/TotemBionet",
    description = "smbionet librairie python",
    long_description = open("README.rst").read(),
    install_requires = ["py4j"],
    license="WTFPL",
    include_package_data = True,
    packages = find_packages(),
    classifiers=[
        "Intended Audience :: Science/Research",
        "Topic :: Scientific/Engineering :: Bio-Informatics",
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    keywords="jupyter, computational systems biology",
)


from py4j.java_gateway import JavaGateway


gateway = JavaGateway()
smbionet = gateway.entry_point.getSmbionet();



class SmbionetException(Exception):
    def __init__(self, message=None, cause=None):
        self.message = message
        self.cause = cause
    
    def __str__(self):
        return self.message or str(self.cause)



def addGrapheInfluence(graphe):
    smbionet.generateInputFile(graphe)
    return graphe

def addCTL(ctl):
    smbionet.addCTL(ctl)
    return ctl

def runSMBionet():
    smbionet.run()
    return "SMBionet is running"

def resultSMBionet():
    return smbionet.result()
